@@ -13,6 +13,7 @@ from .constants import (
     ES_RECONNECTING,
     ES_START_UPDATES,
     ES_STOP_UPDATES,
+    PROTO_ISY,
     SYSTEM_BUSY,
     SYSTEM_STATUS,
     URL_QUERY,
@@ -202,6 +203,11 @@ class ISY:
         """Return the hostname."""
         return self._hostname
 
+    @property
+    def protocol(self):
+        """Return the protocol for this entity."""
+        return PROTO_ISY
+
     @property
     def uuid(self):
         """Return the ISY's uuid."""
